#define G_LOG_DOMAIN "gpod-feed-manager"

#include "config.h"

#include "gpod-feed.h"
#include "gpod-feed-item.h"
#include "gpod-feed-parser.h"
#include "gpod-feed-manager.h"

#include <libsoup/soup.h>

#include <libxml/tree.h>
#include <libxml/parser.h>

#include <gdk/gdk.h>
#include <gtk/gtk.h>
#include <glib/gi18n.h>

/**
 * SECTION:gpod-feed-manager
 * @title: GpodFeedManager
 * @short_description: A #GtkBox widget for list feeds
 * @include: gpod-feed-manager.h
 * @see_also: #GpodFeed, #GpodFeedWidget
 *
 * The #GpodFeedManager is an instance #GtkBox, and acts as the primary
 * window/widget for listing feeds in the #GpodWindow<!-- -->'s #GtkStack.
 **/

struct _GpodFeedManager
{
    GObject parent;
};

G_DEFINE_TYPE (GpodFeedManager, gpod_feed_manager, G_TYPE_OBJECT)

void
add_feed (GpodFeedManager *self,
          GpodFeed        *feed)
{

}

/*
 * gpod_feed_manager_finalize:
 * @object: An instance of #GpodFeedManager
 *
 * Does any last minute clean-ups when the class ends.
 */
static void
gpod_feed_manager_finalize (GObject *object)
{
    G_OBJECT_CLASS (gpod_feed_manager_parent_class)->finalize(object);
}

/*
 * gpod_feed_manager_init:
 * @self: An instance of #GpodFeedManager
 *
 * Initializes various aspects of the #GpodFeedManager. Anything the #GpodFeedManager
 * would need before becoming presented should be done here.
 */
static void
gpod_feed_manager_init (GpodFeedManager *self)
{

}

/*
 * gpod_feed_manager_class_init:
 * @klass: An instance of #GpodFeedManagerClass
 *
 * Initializes the various virtural functions in #GpodFeedManagerClass. In
 * addtition it connects the various #GtkWidgets from the gresource file using
 * gtk_widget_class_set_template_from_resource().
 */
static void
gpod_feed_manager_class_init (GpodFeedManagerClass *klass)
{
    GObjectClass *object_class = G_OBJECT_CLASS (klass);

    object_class->finalize = gpod_feed_manager_finalize;
}

/**
 * gpod_feed_manager_new:
 *
 * Creates a new #GpodFeedManager, a custom widget to show all feeds user is
 * subscribed to.
 *
 * ## Usage
 * |[
 * GpodFeedManager *feed_manager;
 *
 * feed_manager = gpod_feed_manager_new ();
 * ]|
 *
 * Returns: #GpodFeedManager
 */
GpodFeedManager *
gpod_feed_manager_new ()
{
    return g_object_new (GPOD_TYPE_FEED_MANAGER,
                         NULL);
}



void
gpod_feed_manager_add_feed (GpodFeedManager *self,
                            GpodFeed        *feed)
{
    add_feed (self, feed);
}

void
gpod_feed_manager_add_feed_by_uri (GpodFeedManager *self,
                                   gchar           *feed_uri)
{
    GpodFeedParser *feed_parser;
    //GpodFeed *feed;

    feed_parser = gpod_feed_parser_new ();
    //feed = gpod_feed_parser_parse_xml_from_uri (feed_parser, feed_uri);

    //add_feed (self, feed);
    //
    gpod_feed_parser_save_data_from_uri (feed_parser,
                                         "http://h3h3roost.libsyn.com/rss",
                                         g_build_filename (g_get_user_cache_dir (), PACKAGE, "feed", NULL));
}
